@@ -11,16 +11,6 @@
 static grn_ctx *ctx = &PGrnContext;
 static struct PGrnBuffers *buffers = &PGrnBuffers;
 
-static void
-PGrnCreateSourcesCtidColumn(PGrnCreateData *data)
-{
-	data->sourcesCtidColumn = PGrnCreateColumn(data->index,
-											   data->sourcesTable,
-											   PGrnSourcesCtidColumnName,
-											   GRN_OBJ_COLUMN_SCALAR,
-											   grn_ctx_at(ctx, GRN_DB_UINT64));
-}
-
 void
 PGrnCreateSourcesTable(PGrnCreateData *data)
 {
@@ -28,28 +18,14 @@ PGrnCreateSourcesTable(PGrnCreateData *data)
 
 	snprintf(buildingSourcesTableName, sizeof(buildingSourcesTableName),
 			 PGrnBuildingSourcesTableNameFormat, data->relNode);
-	if (PGrnIsAccessorAliasAvailable)
-	{
-		data->sourcesTable = PGrnCreateTable(data->index,
-											 buildingSourcesTableName,
-											 GRN_OBJ_TABLE_HASH_KEY,
-											 grn_ctx_at(ctx, GRN_DB_UINT64),
-											 NULL,
-											 NULL,
-											 NULL);
-		data->sourcesCtidColumn = NULL;
-	}
-	else
-	{
-		data->sourcesTable = PGrnCreateTable(data->index,
-											 buildingSourcesTableName,
-											 GRN_OBJ_TABLE_NO_KEY,
-											 NULL,
-											 NULL,
-											 NULL,
-											 NULL);
-		PGrnCreateSourcesCtidColumn(data);
-	}
+	data->sourcesTable = PGrnCreateTable(data->index,
+										 buildingSourcesTableName,
+										 GRN_OBJ_TABLE_HASH_KEY,
+										 grn_ctx_at(ctx, GRN_DB_UINT64),
+										 NULL,
+										 NULL,
+										 NULL);
+	data->sourcesCtidColumn = NULL;
 }
 
 void
@@ -90,13 +66,12 @@ PGrnCreateDataColumn(PGrnCreateData *data)
 	if (data->attributeFlags & GRN_OBJ_VECTOR)
 	{
 		flags |= GRN_OBJ_COLUMN_VECTOR;
-		compressable = PGrnIsVectorCompressionAvailable;
 	}
 	else
 	{
 		flags |= GRN_OBJ_COLUMN_SCALAR;
-		compressable = true;
 	}
+	compressable = true;
 
 	if (compressable &&
 		(PGrnIsLZ4Available || PGrnIsZlibAvailable || PGrnIsZstdAvailable))
@@ -139,7 +114,7 @@ PGrnCreateLexicon(PGrnCreateData *data)
 {
 	grn_id typeID = GRN_ID_NIL;
 	char lexiconName[GRN_TABLE_MAX_KEY_SIZE];
-	grn_table_flags flags = GRN_OBJ_TABLE_PAT_KEY;
+	grn_table_flags flags = 0;
 	grn_obj *type;
 	grn_obj *lexicon;
 	grn_obj *tokenizer = NULL;
@@ -186,7 +161,12 @@ PGrnCreateLexicon(PGrnCreateData *data)
 							  useCase,
 							  &tokenizer, tokenizerName,
 							  &normalizer, normalizerName,
-							  tokenFilters);
+							  tokenFilters,
+							  &flags);
+	}
+	else
+	{
+		flags |= GRN_OBJ_TABLE_PAT_KEY;
 	}
 
 	snprintf(lexiconName, sizeof(lexiconName),
